@@ -378,7 +378,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/scalc/guide/super_subscript.html">文字上标/下标</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/row_height.html">改变行高或列宽</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/cellstyle_conditional.html">应用条件格式</a></li>\
-    <li><a target="_top" href="zh-CN/text/scalc/guide/cellstyle_minusvalue.html">突出显示负数</a></li>\
+    <li><a target="_top" href="zh-CN/text/scalc/guide/cellstyle_minusvalue.html">高亮显示负数</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/cellstyle_by_formula.html">根据公式指定的格式</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/integer_leading_zero.html">输入带前置零的数字</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/format_table.html">格式化电子表格</a></li>\
